check_names Verify for the required column names in the data object.
Source:R/rbms_toolbox.r
check_names.Rdcheck_names Verify for the required column names in the data object.
Value
Verifyies if column names listed in y are found in the data set x, if not, a message identifies the
missing column name and stops.
Author
Reto Schmucki - retoshm@ceh.ac.uk