R/rbms_toolbox.r
check_package.Rdcheck_package Internal function to check if a package is installed.
check_package(
pkgName = NULL,
message1 = "You need to install ",
message2 = "This version requires"
)If package is not found, the user is offered the option to install the missing package.