collated_index_old compute a collated index from the site indices, using a Generalized Linear Model.
Source:R/rbms_index_modelling.r
collated_index_old.Rdcollated_index_old compute a collated index from the site indices, using a Generalized Linear Model.
Usage
collated_index_old(site_indices, GlmWeight = NULL, GlmFamily = poisson())Value
a list of three objects, a vector of site, a glm model object, and a vector of collated indices per year.
Author
Reto Schmucki - retoshm@ceh.ac.uk