initiate_project Build the folder structure for a generic research project
Source:R/rbms_toolbox.r
initiate_project.Rdinitiate_project Build the folder structure for a generic research project
Author
Reto Schmucki - retoshm@ceh.ac.uk
R/rbms_toolbox.r
initiate_project.Rdinitiate_project Build the folder structure for a generic research project
Reto Schmucki - retoshm@ceh.ac.uk