site_index Extract abundance indices per site and year based on flight curve imputation.
Source:R/rbms_index_modelling.r
site_index.Rdsite_index Extract abundance indices per site and year based on flight curve imputation.
Arguments
- butterfly_count
data.table Observed and imputed weekly or daily counts and the estimated total counts (SINDEX) computed by the function impute_count().
- MinFC
numeric Value between 0 and 1 to define the threshold for the proportion of the flight curve covered by the visits, if NULL all site-year available indices are returned.
Value
data.table Estimated annual abundance index and the proportion of the flight curve covered by the visit - total weekly or daily count over the entire monitoring season.
Author
Reto Schmucki - retoshm@ceh.ac.uk