R/rbms_index_modelling.r
boot_sample.Rd
boot_sample Generate n bootstrap sample of the monitoring sites to be used for each iteration.
boot_sample(data, boot_n = 1000)
data.table or data.frame Data with all site id.
integer The number of bootstrap samples to be generated.
A list with site id and bootstrap indices for n bootstrap sample.
impute_count, collated_index
Reto Schmucki - retoshm@ceh.ac.uk