R/rbms_organize_data.r
ts_dwmy_table.Rdts_dwmy_table Generate a time-series of dates with day, week, month and year (dwmy) from one initial to an end years
a data.table object with the date, the day since the first date, the week since the first week, the year, the month, the day in the month, the ISO week number and the day in the week.