R/rbms_organize_data.r
ts_monit_count_site.Rdts_monit_count_site Generate a full time series of observed count, for all sites and each day since a starting and ending years of the defined time-series
ts_monit_count_site(
m_season_visit,
m_count,
sp = 1,
DateFormat = "%Y-%m-%d"
)A data.table with a complete time-series where absences (0) and recorded counts for a specific species are implemented for each site.